==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/AbsolutePanelBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { PanelBridge } from "./PanelBridge";
import { INativeUIAbsolutePanelBridge_$type } from "./INativeUIAbsolutePanelBridge";
import { markType } from "./type";
import { stringReplace } from "./string";
/**
 * @hidden
 */
var AbsolutePanelBridge = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AbsolutePanelBridge, _super);
    function AbsolutePanelBridge() {
        return _super.call(this) || this;
    }
    AbsolutePanelBridge.prototype.addHandler = function (a, b, c, d) {
    };
    AbsolutePanelBridge.prototype.getX = function (a, b) {
        var c = b.v.getStyleProperty("left");
        stringReplace(c, "px", "");
        var d = parseFloat(c);
        return d;
    };
    AbsolutePanelBridge.prototype.getY = function (a, b) {
        var c = b.v.getStyleProperty("top");
        stringReplace(c, "px", "");
        var d = parseFloat(c);
        return d;
    };
    AbsolutePanelBridge.prototype.getValue = function (a, b) {
        switch (b) {
        }
        return null;
    };
    AbsolutePanelBridge.prototype.removeHandler = function (a, b, c, d) {
    };
    AbsolutePanelBridge.prototype.setX = function (a, b, c) {
        b.v.setStyleProperty("left", c.toString() + "px");
    };
    AbsolutePanelBridge.prototype.setY = function (a, b, c) {
        b.v.setStyleProperty("top", c.toString() + "px");
    };
    AbsolutePanelBridge.prototype.setValue = function (a, b, c) {
        switch (b) {
        }
    };
    AbsolutePanelBridge.prototype.getChildAt = function (a, b) {
        return this.c.apply(this, arguments);
    };
    AbsolutePanelBridge.prototype.removeChildAt = function (a, b) {
        this.h.apply(this, arguments);
    };
    AbsolutePanelBridge.prototype.addChild = function (a, b) {
        this.f.apply(this, arguments);
    };
    AbsolutePanelBridge.prototype.removeChild = function (a, b) {
        this.g.apply(this, arguments);
    };
    AbsolutePanelBridge.prototype.getChildrenCount = function (a) {
        return this.e.apply(this, arguments);
    };
    AbsolutePanelBridge.$t = markType(AbsolutePanelBridge, 'AbsolutePanelBridge', PanelBridge.$, [INativeUIAbsolutePanelBridge_$type]);
    return AbsolutePanelBridge;
}(PanelBridge));
export { AbsolutePanelBridge };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/AbsolutePanelBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { PanelBridge } from "./PanelBridge";
import { INativeUIAbsolutePanelBridge_$type } from "./INativeUIAbsolutePanelBridge";
import { markType } from "./type";
import { stringReplace } from "./string";
/**
 * @hidden
 */
var AbsolutePanelBridge = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AbsolutePanelBridge, _super);
    function AbsolutePanelBridge() {
        return _super.call(this) || this;
    }
    AbsolutePanelBridge.prototype.addHandler = function (a, b, c, d) {
    };
    AbsolutePanelBridge.prototype.getX = function (a, b) {
        var c = b.x.getStyleProperty("left");
        stringReplace(c, "px", "");
        var d = parseFloat(c);
        return d;
    };
    AbsolutePanelBridge.prototype.getY = function (a, b) {
        var c = b.x.getStyleProperty("top");
        stringReplace(c, "px", "");
        var d = parseFloat(c);
        return d;
    };
    AbsolutePanelBridge.prototype.getValue = function (a, b) {
        switch (b) {
        }
        return null;
    };
    AbsolutePanelBridge.prototype.removeHandler = function (a, b, c, d) {
    };
    AbsolutePanelBridge.prototype.setX = function (a, b, c) {
        b.x.setStyleProperty("position", "absolute");
        b.x.setStyleProperty("left", c.toString() + "px");
    };
    AbsolutePanelBridge.prototype.setY = function (a, b, c) {
        b.x.setStyleProperty("position", "absolute");
        b.x.setStyleProperty("top", c.toString() + "px");
    };
    AbsolutePanelBridge.prototype.setValue = function (a, b, c) {
        switch (b) {
        }
    };
    AbsolutePanelBridge.prototype.getChildAt = function (a, b) {
        return this.c.apply(this, arguments);
    };
    AbsolutePanelBridge.prototype.removeChildAt = function (a, b) {
        this.i.apply(this, arguments);
    };
    AbsolutePanelBridge.prototype.addChild = function (a, b) {
        this.f.apply(this, arguments);
    };
    AbsolutePanelBridge.prototype.insertChild = function (a, b, c) {
        this.g.apply(this, arguments);
    };
    AbsolutePanelBridge.prototype.removeChild = function (a, b) {
        this.h.apply(this, arguments);
    };
    AbsolutePanelBridge.prototype.getChildrenCount = function (a) {
        return this.e.apply(this, arguments);
    };
    AbsolutePanelBridge.$t = markType(AbsolutePanelBridge, 'AbsolutePanelBridge', PanelBridge.$, [INativeUIAbsolutePanelBridge_$type]);
    return AbsolutePanelBridge;
}(PanelBridge));
export { AbsolutePanelBridge };
